@@ -40,8 +40,6 @@
 
 namespace aria2 {
 
-class Logger;
-
 class AbstractDiskWriter : public DiskWriter {
 private:
   std::string filename_;
@@ -49,10 +47,6 @@ private:
 
   bool readOnly_;
 
-  bool directIOAllowed_;
-
-  Logger* logger_;
-
   ssize_t writeDataInternal(const unsigned char* data, size_t len);
   ssize_t readDataInternal(unsigned char* data, size_t len);
 
@@ -80,12 +74,6 @@ public:
 
   virtual uint64_t size();
   
-  virtual void enableDirectIO();
-
-  virtual void disableDirectIO();
-
-  virtual void allowDirectIO() { directIOAllowed_ = true; }
-
   virtual void enableReadOnly();
 
   virtual void disableReadOnly();
