@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BINARY_STREAM_H_
-#define _D_BINARY_STREAM_H_
+#ifndef D_BINARY_STREAM_H
+#define D_BINARY_STREAM_H
 
 #include "common.h"
 
@@ -58,14 +58,10 @@ public:
   // Allocates given length bytes of disk space from given offset. The
   // default implementation does nothing.
   virtual void allocate(off_t offset, uint64_t length) {}
-
-  virtual void enableDirectIO() = 0;
-
-  virtual void disableDirectIO() = 0;
 };
 
 typedef SharedHandle<BinaryStream> BinaryStreamHandle;
 
 } // namespace aria2
 
-#endif // _D_BINARY_STREAM_H_
+#endif // D_BINARY_STREAM_H
