@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_CONNECTION_IMPL_H_
-#define _D_DHT_CONNECTION_IMPL_H_
+#ifndef D_DHT_CONNECTION_IMPL_H
+#define D_DHT_CONNECTION_IMPL_H
 
 #include "DHTConnection.h"
 #include "SharedHandle.h"
@@ -42,47 +42,49 @@
 namespace aria2 {
 
 class SocketCore;
-class Logger;
 
 class DHTConnectionImpl:public DHTConnection {
 private:
-  SharedHandle<SocketCore> _socket;
+  SharedHandle<SocketCore> socket_;
 
-  Logger* _logger;
+  int family_;
 public:
-  DHTConnectionImpl();
+  DHTConnectionImpl(int family);
 
   virtual ~DHTConnectionImpl();
 
   /**
-   * Binds port. All number in ports are tried.
-   * If successful, the binded port is assigned to port and returns true.
-   * Otherwise return false and port is undefined in this case.
+   * Binds port. All number in ports are tried.  If successful, the
+   * binded port is assigned to port and returns true.  Otherwise
+   * return false and port is undefined in this case.  If non-empty
+   * string addr is given, the socket is associated to the address.
    */
-  bool bind(uint16_t& port, IntSequence& ports);
+  bool bind(uint16_t& port, const std::string& addr, IntSequence& ports);
   
   /**
    * Binds port. The port number specified by port is used to bind.
-   * If successful, the binded port is assigned to port and returns true.
-   * Otherwise return false and port is undefined in this case.
+   * If successful, the binded port is assigned to port and returns
+   * true.  Otherwise return false and port is undefined in this case.
+   * If non-empty string addr is given, the socket is associated to
+   * the address.
    *
    * If you want to bind arbitrary port, give 0 as port and if successful,
    * the binded port is assigned to port.
    */
-  bool bind(uint16_t& port);
+  bool bind(uint16_t& port, const std::string& addr);
 
   virtual ssize_t receiveMessage(unsigned char* data, size_t len,
-				 std::string& host, uint16_t& port);
+                                 std::string& host, uint16_t& port);
 
   virtual ssize_t sendMessage(const unsigned char* data, size_t len,
-			      const std::string& host, uint16_t port);
+                              const std::string& host, uint16_t port);
 
   const SharedHandle<SocketCore>& getSocket() const
   {
-    return _socket;
+    return socket_;
   }
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_CONNECTION_IMPL_H_
+#endif // D_DHT_CONNECTION_IMPL_H
