@@ -49,9 +49,24 @@
 #include "DownloadContext.h"
 #include "wallclock.h"
 #include "fmt.h"
+#include "BtRegistry.h"
 
 namespace aria2 {
 
+namespace {
+
+const time_t GET_PEER_INTERVAL = (15*60);
+// Interval when the size of peer list is low.
+const time_t GET_PEER_INTERVAL_LOW = (5*60);
+// Interval when the peer list is empty.
+const time_t GET_PEER_INTERVAL_ZERO = 60;
+// Interval for retry.
+const time_t GET_PEER_INTERVAL_RETRY = 5;
+// Maximum retries. Try more than 5 to drop bad node.
+const size_t MAX_RETRIES = 10;
+
+} // namespace
+
 DHTGetPeersCommand::DHTGetPeersCommand
 (cuid_t cuid,
  RequestGroup* requestGroup,
@@ -75,23 +90,35 @@ bool DHTGetPeersCommand::execute()
   if(btRuntime_->isHalt()) {
     return true;
   }
+  time_t elapsed = lastGetPeerTime_.difference(global::wallclock);
   if(!task_ &&
-     ((numRetry_ > 0 &&
-       lastGetPeerTime_.difference(global::wallclock) >= (time_t)numRetry_*5) ||
-      lastGetPeerTime_.difference(global::wallclock) >= GET_PEER_INTERVAL ||
-      (btRuntime_->lessThanMinPeers() &&
-       lastGetPeerTime_.difference(global::wallclock) >= GET_PEER_MIN_INTERVAL
+     (elapsed >= GET_PEER_INTERVAL ||
+      (((btRuntime_->lessThanMinPeers() &&
+         ((numRetry_ && elapsed >= GET_PEER_INTERVAL_RETRY) ||
+          elapsed >= GET_PEER_INTERVAL_LOW)) ||
+        (btRuntime_->getConnections() == 0 &&
+         elapsed >= GET_PEER_INTERVAL_ZERO))
        && !requestGroup_->downloadFinished()))) {
     A2_LOG_DEBUG(fmt("Issuing PeerLookup for infoHash=%s",
                      bittorrent::getInfoHashString
                      (requestGroup_->getDownloadContext()).c_str()));
     task_ = taskFactory_->createPeerLookupTask
-      (requestGroup_->getDownloadContext(), btRuntime_, peerStorage_);
+      (requestGroup_->getDownloadContext(),
+       e_->getBtRegistry()->getTcpPort(),
+       peerStorage_);
     taskQueue_->addPeriodicTask2(task_);
   } else if(task_ && task_->finished()) {
+    A2_LOG_DEBUG("task finished detected");
     lastGetPeerTime_ = global::wallclock;
-    if(numRetry_ < MAX_RETRIES && btRuntime_->lessThanMinPeers()) {
+    if(numRetry_ < MAX_RETRIES &&
+       (btRuntime_->getMaxPeers() == 0 ||
+        btRuntime_->getMaxPeers() > peerStorage_->countPeer())) {
       ++numRetry_;
+      A2_LOG_DEBUG(fmt("Too few peers. peers=%lu, max_peers=%lu."
+                       " Try again(%lu)",
+                       static_cast<unsigned long>(peerStorage_->countPeer()),
+                       static_cast<unsigned long>(btRuntime_->getMaxPeers()),
+                       static_cast<unsigned long>(numRetry_)));
     } else {
       numRetry_ = 0;
     }
