@@ -39,6 +39,7 @@
 
 #include <deque>
 #include <vector>
+#include <string>
 
 #include "SharedHandle.h"
 
@@ -48,7 +49,6 @@ class Peer;
 class DHTPeerAnnounceEntry;
 class DHTTaskQueue;
 class DHTTaskFactory;
-class Logger;
 
 class DHTPeerAnnounceStorage {
 private:
@@ -59,8 +59,6 @@ private:
   SharedHandle<DHTTaskQueue> taskQueue_;
 
   SharedHandle<DHTTaskFactory> taskFactory_;
-
-  Logger* logger_;
 public:
   DHTPeerAnnounceStorage();
 
