@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_BT_INTERACTIVE_H_
-#define _D_DEFAULT_BT_INTERACTIVE_H_
+#ifndef D_DEFAULT_BT_INTERACTIVE_H
+#define D_DEFAULT_BT_INTERACTIVE_H
 
 #include "BtInteractive.h"
 
@@ -58,7 +58,6 @@ class PeerConnection;
 class ExtensionMessageFactory;
 class ExtensionMessageRegistry;
 class DHTNode;
-class Logger;
 class RequestGroupMan;
 class UTMetadataRequestFactory;
 class UTMetadataRequestTracker;
@@ -98,50 +97,53 @@ public:
 
 class DefaultBtInteractive : public BtInteractive {
 private:
-  cuid_t cuid;
+  cuid_t cuid_;
 
-  SharedHandle<DownloadContext> _downloadContext;
+  SharedHandle<DownloadContext> downloadContext_;
 
-  SharedHandle<BtRuntime> _btRuntime;
+  SharedHandle<BtRuntime> btRuntime_;
 
-  SharedHandle<PieceStorage> _pieceStorage;
+  SharedHandle<PieceStorage> pieceStorage_;
 
-  SharedHandle<PeerStorage> _peerStorage;
+  SharedHandle<PeerStorage> peerStorage_;
 
-  SharedHandle<Peer> peer;
+  SharedHandle<Peer> peer_;
 
-  SharedHandle<BtMessageReceiver> btMessageReceiver;
-  SharedHandle<BtMessageDispatcher> dispatcher;
-  SharedHandle<BtRequestFactory> btRequestFactory;
-  SharedHandle<PeerConnection> peerConnection;
-  SharedHandle<BtMessageFactory> messageFactory;
-  SharedHandle<ExtensionMessageFactory> _extensionMessageFactory;
-  SharedHandle<ExtensionMessageRegistry> _extensionMessageRegistry;
-  SharedHandle<UTMetadataRequestFactory> _utMetadataRequestFactory;
-  SharedHandle<UTMetadataRequestTracker> _utMetadataRequestTracker;
+  SharedHandle<BtMessageReceiver> btMessageReceiver_;
+  SharedHandle<BtMessageDispatcher> dispatcher_;
+  SharedHandle<BtRequestFactory> btRequestFactory_;
+  // Although peerStorage_ is not used in this class, this object
+  // holds the reference so that peerConnection_ is not deleted.
+  SharedHandle<PeerConnection> peerConnection_;
+  SharedHandle<BtMessageFactory> messageFactory_;
+  SharedHandle<ExtensionMessageFactory> extensionMessageFactory_;
+  SharedHandle<ExtensionMessageRegistry> extensionMessageRegistry_;
+  SharedHandle<UTMetadataRequestFactory> utMetadataRequestFactory_;
+  SharedHandle<UTMetadataRequestTracker> utMetadataRequestTracker_;
 
-  bool _metadataGetMode;
+  bool metadataGetMode_;
 
-  WeakHandle<DHTNode> _localNode;
+  DHTNode* localNode_;
 
-  Logger* logger;
-  size_t allowedFastSetSize;
-  Timer haveTimer;
-  Timer keepAliveTimer;
-  Timer floodingTimer;
-  FloodingStat floodingStat;
-  Timer inactiveTimer;
-  Timer _pexTimer;
-  Timer _perSecTimer;
-  time_t keepAliveInterval;
-  bool _utPexEnabled;
-  bool _dhtEnabled;
+  size_t allowedFastSetSize_;
+  Timer haveTimer_;
+  Timer keepAliveTimer_;
+  Timer floodingTimer_;
+  FloodingStat floodingStat_;
+  Timer inactiveTimer_;
+  Timer pexTimer_;
+  Timer perSecTimer_;
+  time_t keepAliveInterval_;
+  bool utPexEnabled_;
+  bool dhtEnabled_;
 
-  size_t _numReceivedMessage;
+  size_t numReceivedMessage_;
 
-  size_t _maxOutstandingRequest;
+  size_t maxOutstandingRequest_;
 
-  WeakHandle<RequestGroupMan> _requestGroupMan;
+  RequestGroupMan* requestGroupMan_;
+
+  uint16_t tcpPort_;
 
   static const time_t FLOODING_CHECK_INTERVAL = 5;
 
@@ -191,7 +193,7 @@ public:
 
   void setCuid(cuid_t cuid)
   {
-    this->cuid = cuid;
+    cuid_ = cuid;
   }
 
   void setBtRuntime(const SharedHandle<BtRuntime>& btRuntime);
@@ -218,42 +220,47 @@ public:
   void setExtensionMessageRegistry
   (const SharedHandle<ExtensionMessageRegistry>& registry)
   {
-    _extensionMessageRegistry = registry;
+    extensionMessageRegistry_ = registry;
   }
 
   void setKeepAliveInterval(time_t keepAliveInterval) {
-    this->keepAliveInterval = keepAliveInterval;
+    keepAliveInterval_ = keepAliveInterval;
   }
 
   void setUTPexEnabled(bool f)
   {
-    _utPexEnabled = f;
+    utPexEnabled_ = f;
   }
 
-  void setLocalNode(const WeakHandle<DHTNode>& node);
+  void setLocalNode(DHTNode* node);
 
   void setDHTEnabled(bool f)
   {
-    _dhtEnabled = f;
+    dhtEnabled_ = f;
   }
 
-  void setRequestGroupMan(const WeakHandle<RequestGroupMan>& rgman);
+  void setRequestGroupMan(RequestGroupMan* rgman);
 
   void setUTMetadataRequestTracker
   (const SharedHandle<UTMetadataRequestTracker>& tracker)
   {
-    _utMetadataRequestTracker = tracker;
+    utMetadataRequestTracker_ = tracker;
   }
 
   void setUTMetadataRequestFactory
   (const SharedHandle<UTMetadataRequestFactory>& factory)
   {
-    _utMetadataRequestFactory = factory;
+    utMetadataRequestFactory_ = factory;
   }
 
   void enableMetadataGetMode()
   {
-    _metadataGetMode = true;
+    metadataGetMode_ = true;
+  }
+
+  void setTcpPort(uint16_t port)
+  {
+    tcpPort_ = port;
   }
 };
 
@@ -261,4 +268,4 @@ typedef SharedHandle<DefaultBtInteractive> DefaultBtInteractiveHandle;
 
 } // namespace aria2
 
-#endif // _D_DEFAULT_BT_INTERACTIVE_H_
+#endif // D_DEFAULT_BT_INTERACTIVE_H
