@@ -51,11 +51,15 @@
 namespace aria2 {
 
 namespace {
-const int MAX_PEER_LIST_SIZE = 1024;
+
+const size_t MAX_PEER_LIST_SIZE = 1024;
+const size_t MAX_PEER_LIST_UPDATE = 100;
+
 } // namespace
 
 DefaultPeerStorage::DefaultPeerStorage()
-  : removedPeerSessionDownloadLength_(0),
+  : maxPeerListSize_(MAX_PEER_LIST_SIZE),
+    removedPeerSessionDownloadLength_(0),
     removedPeerSessionUploadLength_(0),
     seederStateChoke_(new BtSeederStateChoke()),
     leecherStateChoke_(new BtLeecherStateChoke()),
@@ -89,18 +93,6 @@ bool DefaultPeerStorage::isPeerAlreadyAdded(const SharedHandle<Peer>& peer)
                       FindIdenticalPeer(peer)) != peers_.end();
 }
 
-namespace {
-size_t calculateMaxPeerListSize(const SharedHandle<BtRuntime>& btRuntime)
-{
-  if(!btRuntime) {
-    return MAX_PEER_LIST_SIZE;
-  }
-  return btRuntime->getMaxPeers() == 0 ?
-    MAX_PEER_LIST_SIZE :
-    btRuntime->getMaxPeers()+(btRuntime->getMaxPeers() >> 2);
-}
-} // namespace
-
 bool DefaultPeerStorage::addPeer(const SharedHandle<Peer>& peer) {
   if(isPeerAlreadyAdded(peer)) {
     A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
@@ -108,24 +100,41 @@ bool DefaultPeerStorage::addPeer(const SharedHandle<Peer>& peer) {
                      peer->getIPAddress().c_str(), peer->getPort()));
     return false;
   }
-  size_t maxPeerListSize = calculateMaxPeerListSize(btRuntime_);
-  if(peers_.size() >= maxPeerListSize) {
-    deleteUnusedPeer(peers_.size()-maxPeerListSize+1);
+  const size_t peerListSize = peers_.size();
+  if(peerListSize >= maxPeerListSize_) {
+    deleteUnusedPeer(peerListSize-maxPeerListSize_+1);
   }
   peers_.push_front(peer);
+  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
+                   static_cast<unsigned long>(peers_.size())));
   return true;
 }
 
 void DefaultPeerStorage::addPeer(const std::vector<SharedHandle<Peer> >& peers)
 {
+  size_t added = 0;
+  size_t addMax = std::min(maxPeerListSize_, MAX_PEER_LIST_UPDATE);
   for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
-        eoi = peers.end(); itr != eoi; ++itr) {
+        eoi = peers.end(); itr != eoi && added < addMax; ++itr) {
     const SharedHandle<Peer>& peer = *itr;
-    if(addPeer(peer)) {
+    if(isPeerAlreadyAdded(peer)) {
+      A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
+                       " added.",
+                       peer->getIPAddress().c_str(), peer->getPort()));
+      continue;
+    } else {
       A2_LOG_DEBUG(fmt(MSG_ADDING_PEER,
                        peer->getIPAddress().c_str(), peer->getPort()));
     }
-  }  
+    peers_.push_front(peer);
+    ++added;
+  }
+  const size_t peerListSize = peers_.size();
+  if(peerListSize >= maxPeerListSize_) {
+    deleteUnusedPeer(peerListSize-maxPeerListSize_);
+  }
+  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
+                   static_cast<unsigned long>(peers_.size())));
 }
 
 void DefaultPeerStorage::addDroppedPeer(const SharedHandle<Peer>& peer)
@@ -237,7 +246,8 @@ TransferStat calculateStatFor(const SharedHandle<Peer>& peer)
 TransferStat DefaultPeerStorage::calculateStat()
 {
   TransferStat stat;
-  if(lastTransferStatMapUpdated_.differenceInMillis(global::wallclock) >= 250) {
+  if(lastTransferStatMapUpdated_.differenceInMillis(global::wallclock)+
+     A2_DELTA_MILLIS >= 250) {
     A2_LOG_DEBUG("Updating TransferStat of PeerStorage");
     lastTransferStatMapUpdated_ = global::wallclock;
     peerTransferStatMap_.clear();
