@@ -35,11 +35,12 @@
 #include "NsCookieParser.h"
 
 #include <fstream>
+#include <limits>
 
 #include "util.h"
 #include "A2STR.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "Cookie.h"
 #include "cookie_helper.h"
 
@@ -51,7 +52,7 @@ NsCookieParser::~NsCookieParser() {}
 
 namespace {
 const std::string C_TRUE("TRUE");
-}
+} // namespace
 
 namespace {
 bool parseNsCookie
@@ -70,12 +71,15 @@ bool parseNsCookie
   if(!util::parseLLIntNoThrow(expiryTime, vs[4])) {
     return false;
   }
-  if(sizeof(time_t) == 4 && expiryTime > INT32_MAX) {
-    expiryTime = INT32_MAX;
+  if(std::numeric_limits<time_t>::max() < expiryTime) {
+    expiryTime = std::numeric_limits<time_t>::max();
+  } else if(std::numeric_limits<time_t>::min() > expiryTime) {
+    expiryTime = std::numeric_limits<time_t>::min();
   }
   cookie.setName(vs[5]);
   cookie.setValue(vs.size() >= 7? vs[6]:A2STR::NIL);
-  cookie.setExpiryTime(expiryTime == 0?INT32_MAX:expiryTime);
+  cookie.setExpiryTime(expiryTime == 0?
+                       std::numeric_limits<time_t>::max():expiryTime);
   // aria2 treats expiryTime == 0 means session cookie.
   cookie.setPersistent(expiryTime != 0);
   cookie.setDomain(cookieDomain);
@@ -85,15 +89,14 @@ bool parseNsCookie
   cookie.setCreationTime(creationTime);
   return true;
 }
-}
+} // namespace
 
 std::vector<Cookie> NsCookieParser::parse
 (const std::string& filename, time_t creationTime)
 {
   std::ifstream s(filename.c_str(), std::ios::binary);
   if(!s) {
-    throw DL_ABORT_EX
-      (StringFormat("Failed to open file %s", filename.c_str()).str());
+    throw DL_ABORT_EX(fmt("Failed to open file %s", filename.c_str()));
   }
   std::string line;
   std::vector<Cookie> cookies;
