@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PEER_STORAGE_H_
-#define _D_PEER_STORAGE_H_
+#ifndef D_PEER_STORAGE_H
+#define D_PEER_STORAGE_H
 
 #include "common.h"
 
@@ -67,6 +67,12 @@ public:
    */
   virtual const std::deque<SharedHandle<Peer> >& getPeers() = 0;
 
+
+  /**
+   * Returns the number of peers.
+   */
+  virtual size_t countPeer() const = 0;
+
   /**
    * Returns internal dropped peer list.
    */
@@ -111,4 +117,4 @@ typedef SharedHandle<PeerStorage> PeerStorageHandle;
 
 } // namespace aria2
 
-#endif // _D_PEER_STORAGE_H_
+#endif // D_PEER_STORAGE_H
