@@ -71,7 +71,7 @@
 #include "fmt.h"
 #include "A2STR.h"
 #include "URISelector.h"
-#include "InOrderURISelector.h"
+#include "InorderURISelector.h"
 #include "PieceSelector.h"
 #include "a2functional.h"
 #include "SocketCore.h"
@@ -136,7 +136,7 @@ RequestGroup::RequestGroup(const SharedHandle<Option>& option)
     forceHaltRequested_(false),
     haltReason_(RequestGroup::NONE),
     pauseRequested_(false),
-    uriSelector_(new InOrderURISelector()),
+    uriSelector_(new InorderURISelector()),
     lastModifiedTime_(Time::null()),
     fileNotFoundCount_(0),
     timeout_(option->getAsInt(PREF_TIMEOUT)),
@@ -197,9 +197,10 @@ error_code::Value RequestGroup::downloadResult() const
   if(downloadFinished() && !downloadContext_->isChecksumVerificationNeeded())
     return error_code::FINISHED;
   else {
-    if(lastErrorCode_ == error_code::UNDEFINED) {
-      if(haltReason_ == RequestGroup::USER_REQUEST ||
-         haltReason_ == RequestGroup::SHUTDOWN_SIGNAL) {
+    if(haltReason_ == RequestGroup::USER_REQUEST) {
+      return error_code::REMOVED;
+    } else if(lastErrorCode_ == error_code::UNDEFINED) {
+      if(haltReason_ == RequestGroup::SHUTDOWN_SIGNAL) {
         return error_code::IN_PROGRESS;
       } else {
         return error_code::UNKNOWN_ERROR;
@@ -1020,6 +1021,8 @@ void RequestGroup::releaseRuntimeResource(DownloadEngine* e)
 {
 #ifdef ENABLE_BITTORRENT
   e->getBtRegistry()->remove(gid_);
+  btRuntime_ = 0;
+  peerStorage_ = 0;
 #endif // ENABLE_BITTORRENT
   if(pieceStorage_) {
     pieceStorage_->removeAdvertisedPiece(0);
