@@ -38,7 +38,6 @@
 #include <iterator>
 
 #include "RequestGroupMan.h"
-#include "ServerStatMan.h"
 #include "a2functional.h"
 #include "File.h"
 #include "A2STR.h"
@@ -136,10 +135,10 @@ void writeDownloadResult
  const SharedHandle<DownloadResult>& dr)
 {
   const SharedHandle<MetadataInfo>& mi = dr->metadataInfo;
-  if(dr->belongsTo != 0 || (!mi.isNull() && mi->dataOnly())) {
+  if(dr->belongsTo != 0 || (mi && mi->dataOnly())) {
     return;
   }
-  if(mi.isNull()) {
+  if(!mi) {
     // only save first file entry
     if(dr->fileEntries.empty()) {
       return;
@@ -172,9 +171,10 @@ void SessionSerializer::save(std::ostream& out) const
     rgman_->getDownloadResults();
   for(std::deque<SharedHandle<DownloadResult> >::const_iterator itr =
         results.begin(), eoi = results.end(); itr != eoi; ++itr) {
-    if((*itr)->result == downloadresultcode::FINISHED) {
+    if((*itr)->result == error_code::FINISHED ||
+       (*itr)->result == error_code::REMOVED) {
       continue;
-    } else if((*itr)->result == downloadresultcode::IN_PROGRESS) {
+    } else if((*itr)->result == error_code::IN_PROGRESS) {
       if(saveInProgress_) {
         writeDownloadResult(out, metainfoCache, *itr);
       }
@@ -185,18 +185,6 @@ void SessionSerializer::save(std::ostream& out) const
       }
     }
   }
-  if(saveInProgress_) {
-    const std::deque<SharedHandle<RequestGroup> >& groups =
-      rgman_->getRequestGroups();
-    for(std::deque<SharedHandle<RequestGroup> >::const_iterator itr =
-          groups.begin(), eoi = groups.end(); itr != eoi; ++itr) {
-      SharedHandle<DownloadResult> result = (*itr)->createDownloadResult();
-      if(result->result == downloadresultcode::FINISHED) {
-        continue;
-      }
-      writeDownloadResult(out, metainfoCache, result);
-    }
-  }
   if(saveWaiting_) {
     const std::deque<SharedHandle<RequestGroup> >& groups =
       rgman_->getReservedGroups();
@@ -204,6 +192,11 @@ void SessionSerializer::save(std::ostream& out) const
           groups.begin(), eoi = groups.end(); itr != eoi; ++itr) {
       SharedHandle<DownloadResult> result = (*itr)->createDownloadResult();
       writeDownloadResult(out, metainfoCache, result);
+      // PREF_PAUSE was removed from option, so save it here looking
+      // property separately.
+      if((*itr)->isPauseRequested()) {
+        out << " " << PREF_PAUSE << "=true" << "\n";
+      }
     }
   }
 }
