@@ -32,15 +32,17 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_A2IO_H_
-#define _D_A2IO_H_
+#ifndef D_A2IO_H
+#define D_A2IO_H
 #include "common.h"
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <cerrno>
-
+#ifdef HAVE_POLL_H
+# include <poll.h>
+#endif // HAVE_POLL_H
 #ifdef HAVE_IO_H
 # include <io.h>
 #endif // HAVE_IO_H
@@ -135,11 +137,7 @@
 # define a2mkdir(path, openMode) mkdir(path, openMode)
 #endif // !__MINGW32__
 
-#if defined HAVE_POSIX_MEMALIGN && defined O_DIRECT
-# define ENABLE_DIRECT_IO 1
-#endif // HAVE_POSIX_MEMALIGN && O_DIRECT
-
 #define OPEN_MODE S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH
 #define DIR_OPEN_MODE S_IRWXU|S_IRWXG|S_IRWXO
 
-#endif // _D_A2IO_H_
+#endif // D_A2IO_H
