@@ -72,7 +72,6 @@ public:
     peerStorage_->setStat(stat);
 
     btRuntime_.reset(new BtRuntime());
-    btRuntime_->setListenPort(6989);
   }
 
   void tearDown()
@@ -95,8 +94,9 @@ public:
 
 CPPUNIT_TEST_SUITE_REGISTRATION(DefaultBtAnnounceTest);
 
+namespace {
 template<typename InputIterator>
-static SharedHandle<List> createAnnounceTier
+SharedHandle<List> createAnnounceTier
 (InputIterator first, InputIterator last)
 {
   SharedHandle<List> announceTier = List::g();
@@ -105,16 +105,20 @@ static SharedHandle<List> createAnnounceTier
   }
   return announceTier;
 }
+} // namespace
 
-static SharedHandle<List> createAnnounceTier(const std::string& uri)
+namespace {
+SharedHandle<List> createAnnounceTier(const std::string& uri)
 {
   SharedHandle<List> announceTier = List::g();
   announceTier->append(String::g(uri));
   return announceTier;
 }
+} // namespace
 
-static void setAnnounceList(const SharedHandle<DownloadContext>& dctx,
-                            const SharedHandle<List>& announceList)
+namespace {
+void setAnnounceList(const SharedHandle<DownloadContext>& dctx,
+                     const SharedHandle<List>& announceList)
 {
   std::vector<std::vector<std::string> > dest;
   for(List::ValueType::const_iterator tierIter = announceList->begin(),
@@ -130,6 +134,7 @@ static void setAnnounceList(const SharedHandle<DownloadContext>& dctx,
   }
   bittorrent::getTorrentAttrs(dctx)->announceList.swap(dest);
 }
+} // namespace
 
 void DefaultBtAnnounceTest::testNoMoreAnnounce()
 {
@@ -144,6 +149,7 @@ void DefaultBtAnnounceTest::testNoMoreAnnounce()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -192,6 +198,7 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -223,6 +230,7 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl_withQuery()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL
     (std::string("http://localhost/announce?k=v&"
@@ -246,6 +254,7 @@ void DefaultBtAnnounceTest::testGetAnnounceUrl_externalIP()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL
     (std::string("http://localhost/announce?"
@@ -269,6 +278,7 @@ void DefaultBtAnnounceTest::testIsAllAnnounceFailed()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -301,6 +311,7 @@ void DefaultBtAnnounceTest::testURLOrderInStoppedEvent()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
@@ -331,6 +342,7 @@ void DefaultBtAnnounceTest::testURLOrderInCompletedEvent()
   btAnnounce.setPeerStorage(peerStorage_);
   btAnnounce.setBtRuntime(btRuntime_);
   btAnnounce.setRandomizer(SharedHandle<Randomizer>(new FixedNumberRandomizer()));
+  btAnnounce.setTcpPort(6989);
 
   CPPUNIT_ASSERT_EQUAL(std::string("http://localhost1/announce?info_hash=%01%23Eg%89%AB%CD%EF%01%23Eg%89%AB%CD%EF%01%23Eg&peer_id=%2Daria2%2Dultrafastdltl&uploaded=1572864&downloaded=1310720&left=1572864&compact=1&key=fastdltl&numwant=50&no_peer_id=1&port=6989&event=started&supportcrypto=1"), btAnnounce.getAnnounceUrl());
 
